/* ********************************************************* assistant.h *** *
 * $B%"%7%9%?%s%H$K4X$9$k4X?t(B $B%X%C%@%U%!%$%k(B
 *
 * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                    Time-stamp: <03/01/02 21:56:16 sugaya>
 * ************************************************************************* */
#ifndef	__ASSISTANT_H__
#define	__ASSISTANT_H__

#include "dh-html.h"

/* ************************************************************************* */
typedef struct _AssistantSkinData {
  GdkPixmap	*body;
  GdkBitmap	*body_mask;
  GdkPixmap	*msg_box[4];
  GdkBitmap	*msg_box_mask;
  int		width;
  int		height;
  int		xoffset;
  int		yoffset;	
} AssistantSkinData;

/* ************************************************************************* */
GtkWidget*	assistant_new		(const char	*skin_file);
void		assistant_destroy 	(GtkWidget	*assistant);
GtkWidget*	html_window_new 	(void);
void		assistant_set_document 	(DhHtml		*document,
					 const gchar	*uri);
#endif	/* __ASSISTANT_H__ */

/* ************************************************** End of assistant.h *** */
